# eric7.Network.IRC.IrcNetworkEditDialog

Module implementing a dialog for editing IRC network definitions.

### Global Attributes

None

### Classes

IrcNetworkEditDialog | Class implementing a dialog for editing IRC network definitions.

### Functions

None

## IrcNetworkEditDialog

Class implementing a dialog for editing IRC network definitions.

### Derived from

QDialog, Ui_IrcNetworkEditDialog

### Class Attributes

None

### Class Methods

None

### Methods

IrcNetworkEditDialog | Constructor
__editChannel | Private method to edit a channel.
__refreshIdentityCombo | Private method to refresh the identity combo.
__updateOkButton | Private method to update the OK button state.
getNetwork | Public method to get the network object.
on_addChannelButton_clicked | Private slot to add a channel.
on_channelList_itemActivated | Private slot to handle the activation of a channel entry.
on_channelList_itemSelectionChanged | Private slot to handle changes of the selection of channels.
on_deleteChannelButton_clicked | Private slot to delete the selected channel.
on_editChannelButton_clicked | Private slot to edit the selected channel.
on_editIdentitiesButton_clicked | Private slot to edit the identities.
on_editServerButton_clicked | Private slot to edit the server configuration.
on_identityCombo_currentTextChanged | Private slot to handle the selection of an identity.
on_networkEdit_textChanged | Private slot to handle changes of the network name.
on_serverEdit_textChanged | Private slot to handle changes of the server name.

### Static Methods

None

#### IrcNetworkEditDialog (Constructor)

IrcNetworkEditDialog(manager, networkName, parent=None)

Constructor

manager (IrcNetworkManager)
  reference to the IRC network manager object
networkName (str)
  name of the network to work on
parent (QWidget)
  reference to the parent widget

#### IrcNetworkEditDialog.__editChannel

__editChannel(itm)

Private method to edit a channel.

itm (QTreeWidgetItem)
  reference to the item to be edited

#### IrcNetworkEditDialog.__refreshIdentityCombo

__refreshIdentityCombo(currentIdentity)

Private method to refresh the identity combo.

currentIdentity (str)
  name of the identity to select

#### IrcNetworkEditDialog.__updateOkButton

__updateOkButton()

Private method to update the OK button state.

#### IrcNetworkEditDialog.getNetwork

getNetwork()

Public method to get the network object.

Return:
  edited network object

Return Type:
  IrcNetwork

#### IrcNetworkEditDialog.on_addChannelButton_clicked

on_addChannelButton_clicked()

Private slot to add a channel.

#### IrcNetworkEditDialog.on_channelList_itemActivated

on_channelList_itemActivated(item, _column)

Private slot to handle the activation of a channel entry.

item (QTreeWidgetItem)
  reference to the activated item
_column (int)
  column the activation occurred in (unused)

#### IrcNetworkEditDialog.on_channelList_itemSelectionChanged

on_channelList_itemSelectionChanged()

Private slot to handle changes of the selection of channels.

#### IrcNetworkEditDialog.on_deleteChannelButton_clicked

on_deleteChannelButton_clicked()

Private slot to delete the selected channel.

#### IrcNetworkEditDialog.on_editChannelButton_clicked

on_editChannelButton_clicked()

Private slot to edit the selected channel.

#### IrcNetworkEditDialog.on_editIdentitiesButton_clicked

on_editIdentitiesButton_clicked()

Private slot to edit the identities.

#### IrcNetworkEditDialog.on_editServerButton_clicked

on_editServerButton_clicked()

Private slot to edit the server configuration.

#### IrcNetworkEditDialog.on_identityCombo_currentTextChanged

on_identityCombo_currentTextChanged(identity)

Private slot to handle the selection of an identity.

identity (str)
  selected identity

#### IrcNetworkEditDialog.on_networkEdit_textChanged

on_networkEdit_textChanged(_txt)

Private slot to handle changes of the network name.

_txt (str)
  text entered into the network name edit (unused)

#### IrcNetworkEditDialog.on_serverEdit_textChanged

on_serverEdit_textChanged(_txt)

Private slot to handle changes of the server name.

_txt (str)
  text entered into the server name edit (unused)

Up